@@ -52,3 +52,10 @@ def get_running_players():
 			running.append(p)
 		
 	return running
+
+def get_player(player_id):
+	"""Returns a player object if the player's running. None otherwise."""
+	
+	for player in get_running_players():
+		if player.get_id() == player_id:
+			return player
